@@ -1,7 +1,9 @@
 from datetime import datetime, timedelta
 from django.core.management.base import BaseCommand
 from django.core.cache import cache
+from django.conf import settings
 from alert.models import Alert
+from django.contrib.sites.models import Site
 
 
 class CacheRequiredError(Exception): pass
@@ -23,7 +25,7 @@ class Command(BaseCommand):
         one_day = 60*60*24
         cache.set(self._cache_key, True, one_day)
         
-        alerts = Alert.pending.all()
+        alerts = Alert.pending.filter(site=settings.SITE_ID)
         [alert.send() for alert in alerts]
         
         cache.delete(self._cache_key)
